@@ -7,14 +7,19 @@ import json
 import requests
 session = requests.Session()
 
-
+class InfluxDBClientError(Exception):
+    "Raised when an error occures in the Request"
+    def __init__(self, message, code):
+      self.message = message
+      self.code = code
+      
 class InfluxDBClient(object):
     """
     InfluxDB Client
     """
 
     def __init__(self, host='localhost', port=8086, username='root',
-                 password='root', database=None, ssl=False, verify_ssl=False):
+                 password='root', database=None, ssl=False, verify_ssl=False, timeout=0):
         """
         Initialize client
         """
@@ -23,6 +28,7 @@ class InfluxDBClient(object):
         self._username = username
         self._password = password
         self._database = database
+        self._timeout = timeout
 
         self._verify_ssl = verify_ssl
 
@@ -71,9 +77,6 @@ class InfluxDBClient(object):
         """
         url = "{0}/{1}".format(self._baseurl, url)
 
-        if isinstance(data, dict):
-            data = json.dumps(data)
-
         if params is None:
             params = {}
 
@@ -84,20 +87,25 @@ class InfluxDBClient(object):
 
         params.update(auth)
 
+        if data is not None and not isinstance(data, str):
+            data = json.dumps(data)
+
         response = session.request(
             method=method,
             url=url,
             params=params,
             data=data,
             headers=self._headers,
-            verify=self._verify_ssl
+            verify=self._verify_ssl,
+            timeout=self._timeout
             )
 
         if response.status_code == status_code:
             return response
+            
         else:
-            raise Exception(
-                "{0}: {1}".format(response.status_code, response.content))
+            error = InfluxDBClientError("{0}: {1}".format(response.status_code, response.content), response.status_code)
+            raise error
 
     # Writing Data
     #
@@ -163,7 +171,7 @@ class InfluxDBClient(object):
             url=url,
             method='POST',
             params=params,
-            data=json.dumps(data),
+            data=data,
             status_code=200
             )
 
@@ -255,7 +263,13 @@ class InfluxDBClient(object):
             status_code=200
             )
 
-        return json.loads(response.content)
+        try:
+            res = json.loads(response.content)
+        except TypeError:
+            # must decode in python 3 
+            res = json.loads(response.content.decode('utf8'))
+
+        return res
 
     # Creating and Dropping Databases
     #
